Core Helpers for Google Cloud Python Client Library
===================================================

|pypi| |versions|

This library is not meant to stand-alone. Instead it defines
common helpers (e.g. base ``Client`` classes) used by all of the
``google-cloud-*`` packages.


-  `Documentation`_

.. |pypi| image:: https://img.shields.io/pypi/v/google-cloud-core.svg
   :target: https://pypi.org/project/google-cloud-core/
.. |versions| image:: https://img.shields.io/pypi/pyversions/google-cloud-core.svg
   :target: https://pypi.org/project/google-cloud-core/
.. _Documentation: https://googleapis.dev/python/google-cloud-core/latest

Quick Start
-----------

.. code-block:: console

    $ pip install --upgrade google-cloud-core

For more information on setting up your Python development environment,
such as installing ``pip`` and ``virtualenv`` on your system, please refer
to `Python Development Environment Setup Guide`_ for Google Cloud Platform.

.. _Python Development Environment Setup Guide: https://cloud.google.com/python/setup


Supported Python Versions
-------------------------
Python >= 3.6

Deprecated Python Versions
--------------------------
Python == 2.7. Python 2.7 support will be removed on January 1, 2020.
